==> ecos-1.2.1.tar.bz2: ecos-1.2.1/packages/kernel/v1_2_1/include/diag.h <==
#ifndef CYGONCE_KERNEL_DIAG_H
#define CYGONCE_KERNEL_DIAG_H

/*=============================================================================
//
//      diag.h
//
//      Diagnostic Routines for Kernel Development
//
//==========================================================================
//####COPYRIGHTBEGIN####
//
// -------------------------------------------
// The contents of this file are subject to the Cygnus eCos Public License
// Version 1.0 (the "License"); you may not use this file except in
// compliance with the License.  You may obtain a copy of the License at
// http://sourceware.cygnus.com/ecos
// 
// Software distributed under the License is distributed on an "AS IS"
// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the
// License for the specific language governing rights and limitations under
// the License.
// 
// The Original Code is eCos - Embedded Cygnus Operating System, released
// September 30, 1998.
// 
// The Initial Developer of the Original Code is Cygnus.  Portions created
// by Cygnus are Copyright (C) 1998,1999 Cygnus Solutions.  All Rights Reserved.
// -------------------------------------------
//
//####COPYRIGHTEND####
//==========================================================================
//#####DESCRIPTIONBEGIN####
//
// Author(s):   nickg
// Contributors:        nickg
// Date:        1998-03-02
// Purpose:     Diagnostic Routines for Kernel Development
// Description: Diagnostic routines for use during kernel development.
// Usage:       #include <cyg/kernel/diag.h>
//
//####DESCRIPTIONEND####
//
//==========================================================================*/

// These have now migrated to here:

#include <cyg/infra/diag.h>

// this file is retained for the kernel to add to the functionality
// in the knowledge that there _is_ a kernel.

/*---------------------------------------------------------------------------*/
#endif /* CYGONCE_KERNEL_DIAG_H */
/* EOF diag.h */

==> ecos-1.3.1.tar.bz2: ecos-1.3.1/packages/kernel/v1_3_1/include/diag.h <==
#ifndef CYGONCE_KERNEL_DIAG_H
#define CYGONCE_KERNEL_DIAG_H

/*=============================================================================
//
//      diag.h
//
//      Diagnostic Routines for Kernel Development
//
//==========================================================================
//####COPYRIGHTBEGIN####
//                                                                          
// -------------------------------------------                              
// The contents of this file are subject to the Red Hat eCos Public License 
// Version 1.1 (the "License"); you may not use this file except in         
// compliance with the License.  You may obtain a copy of the License at    
// http://www.redhat.com/                                                   
//                                                                          
// Software distributed under the License is distributed on an "AS IS"      
// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the 
// License for the specific language governing rights and limitations under 
// the License.                                                             
//                                                                          
// The Original Code is eCos - Embedded Configurable Operating System,      
// released September 30, 1998.                                             
//                                                                          
// The Initial Developer of the Original Code is Red Hat.                   
// Portions created by Red Hat are                                          
// Copyright (C) 1998, 1999, 2000 Red Hat, Inc.                             
// All Rights Reserved.                                                     
// -------------------------------------------                              
//                                                                          
//####COPYRIGHTEND####
//==========================================================================
//#####DESCRIPTIONBEGIN####
//
// Author(s):   nickg
// Contributors:        nickg
// Date:        1998-03-02
// Purpose:     Diagnostic Routines for Kernel Development
// Description: Diagnostic routines for use during kernel development.
// Usage:       #include <cyg/kernel/diag.h>
//
//####DESCRIPTIONEND####
//
//==========================================================================*/

// These have now migrated to here:

#include <cyg/infra/diag.h>

// this file is retained for the kernel to add to the functionality
// in the knowledge that there _is_ a kernel.

/*---------------------------------------------------------------------------*/
#endif /* CYGONCE_KERNEL_DIAG_H */
/* EOF diag.h */
